@@ -159,7 +159,28 @@ class ChannelDescriptor(LogStatus):
         else:
           self.max = 0
           self.status(C_FILE_NOT_FOUND, "No morph geometry exists for actor[{:s}] at column {:d}", self.actorName, self.no)
-
+          
+      elif self.chanType==PoserToken.E_shaderNodeParm: # check NodeInput Qualified name
+        # Check syntax : MaterialName.NodeName.NodeInputName
+        try:
+          MaterialName, NodeName, NodeInputName = self.groupName.split('.')
+          
+          self.mat = fig.getMaterial(MaterialName)          
+          if not self.mat:
+            return self.status(PoserConst.C_MATERIAL_NOTFOUND, "Unknown material[{:s}] at column {:d}", MaterialName, self.no)
+          
+          self.node = self.mat.getShaderTree().getNodeByInternalName(NodeName)
+          if not self.node:
+            return self.status(PoserConst.C_NODE_NOTFOUND, "Unknown node[{:s}] in Material[{:s}] at column {:d}", NodeName, MaterialName, self.no)
+          
+          self.ni = self.node.getInputByInternalName(NodeInputName)
+          if not self.ni:
+            return self.status(PoserConst.C_NODE_NOTFOUND, "Unknown node input[{:s}] in Node[{:s}] of Material[{:s}] at column {:d}", \
+                               NodeInputName, NodeName, MaterialName, self.no)
+          
+        except ValueError as ve:
+          self.status(PoserConst.C_BAD_QUALNAME, "Incorrect NodeInput Qualified Name [{:s}] at column {:d}", self.groupName, self.no)
+ 
       #else: self.chanType  is PoserToken.E_valueParm or else
 
       self.analyseOps(fig)
@@ -229,9 +250,6 @@ class ChannelDescriptor(LogStatus):
     self.lstOps = ops
     return ret
 
-
-
-
 class ChannelImportAnalysis: # implements PoserConst
   ''' Result of a XLS/XLSX/ODS file import for channel creation
    
