@@ -661,6 +661,9 @@ class PoserMeshedObject(StructuredAttribut):
   def hasCustomData(self):
     return self._customData!=None
 
+  def setCastsShadow(self, b):
+    self._castsShadow = b
+
   # Create in the current MeshedObject the best deltas for the list of morph
   # targets.
   # @param poserRootDir 	To find the .OBJ files
