@@ -53,9 +53,9 @@ class SimpleAttribut(PoserObject):
   def write(self, fw, pfx):
     v = self.getValue()
     if v:
-      fw.write("{0:s}{1:s} {2:s}\n".format(pfx, self.getName(), v))
+      fw.write(f"{pfx}{self.getName()} {v}\n")
     else:
-      fw.write("{0:s}{1:s}\n".format(pfx, self.getName()))
+      fw.write(f"{pfx}{self.getName()}\n")
 
 
 # addchild and weld attributs
@@ -98,13 +98,15 @@ class TextureMapSA(SimpleAttribut):
   def __init__(self, t=None, initPath=None):
     super(TextureMapSA, self).__init__(n=t)
     if initPath:
-      if isinstance(initPath, TextureMapSA):
-        self.setPoserType(initPath.getPoserType())
+      if isinstance(initPath, TextureMapSA):        
+        self.setPoserType(initPath.getPoserType())    
+        self._name = initPath.getName()    
         self.setPath(initPath.getPath())
       else:
         self.setPath("" if initPath==PoserConst.C_NO_MAP else initPath)
     else:
       self._path = ''
+      self._value = PoserConst.C_NO_MAP
       
   def read(self, st, val):
     self._path = val
@@ -449,11 +451,11 @@ class KSA(SimpleAttribut):
     self._flags |= 0x80
 
   def write(self, fw, pfx):
-    fw.write(pfx + "k {0:d} {1:g}\n".format(self._noFrame, self._factor))
-    if (self._flags & 0x80) != 0:
+    fw.write(f"{pfx}k {self._noFrame} {self._factor}\n")
+    if self._flags & 0x80:
       WBoolLine(fw, pfx, "sl", ((self._flags & 0x40) != 0))
-      fw.write(pfx + "spl\n" if ((self._flags & 0x20) != 0) else ("lin\n" if ((self._flags & 0x10) != 0) else "con\n"))
-      fw.write(pfx + ("br\n" if ((self._flags & 0x01) != 0) else "sm\n"))
+      fw.write(f"{pfx}{'spl' if self._flags & 0x20 else ('lin' if self._flags & 0x10 else 'con')}\n")
+      fw.write(f"{pfx}{'br' if self._flags & 0x01 else 'sm'}\n")
 
 #  
 # linkParms attribut
