@@ -31,6 +31,20 @@ C_MISSING_FACEMAT  = -110
 FEPSILON = 1e-6
 FEPSILON2 = FEPSILON*FEPSILON
 
+# -------------------------------------------
+# Face Attributs
+# Face attributs are expressed with a 32bits motif
+#  8 left bits are the binary attributes:
+# 24 right bits are the material index
+#
+C_FACE_NONE     = 0x00000000
+C_FACE_TEXT     = 0x01000000
+C_FACE_NORM     = 0x02000000
+C_FACE_TEXTNORM = C_FACE_TEXT|C_FACE_NORM
+C_FACE_NOTEXT   = not C_FACE_TEXT
+C_FACE_NONROM   = not C_FACE_NORM
+C_FACE_MATMASK  = 0x00ffffff
+
 #
 def getOBJFile(filename):
   ''' Return the file descriptor of a OBJ or OBZ geometry.
@@ -136,6 +150,14 @@ def IndexAdd(l,p):
     l.append(p)
     return i
 
+def SArcCos(a,b):
+  ''' Perform acos( a / b ) with rounding effects '''
+  if math.fabs(b)>FEPSILON:
+    r = a / b
+    r = -1.0 if r<-1.0 else (1.0 if r>1.0 else r)
+    return math.acos(r)
+  else:
+    return 0.0
 
 # Used as base Object for Vector3d
 class Point3d(object):
@@ -448,6 +470,33 @@ class Point3d(object):
     n.normalize()
     return n
 
+  @classmethod
+  def triangle_orientation(cls, p0, p1, p2, AxisOrder='xyz', inDegrees=False):
+    n = Point3d.triangle_normal(p0, p1, p2)
+    
+    rotx, roty, rotz = 0.0,0.0,0.0
+     
+    if AxisOrder=='yzx':
+      rotz = math.asin(-n.x)
+      cz   = math.cos(rotz)
+      rotx = SArcCos(n.y, cz)
+    elif AxisOrder=='xyz':
+      roty = math.asin(n.z)
+      cy   = math.cos(roty)
+      rotz = SArcCos(n.x, cy)
+    else: # 'zxy'
+      rotx = math.asin(-n.y)
+      cx   = math.cos(rotx)
+      roty = SArcCos(n.z, cx)
+    
+    # Convert Result un degree
+    if inDegrees:
+      rotx = math.degrees(rotx)
+      roty = math.degrees(roty)
+      rotz = math.degrees(rotz)
+
+    return (rotx, roty, rotz)
+
   @classmethod
   def barycentre(cls, iterPt:'iterable of Point3d'):
     '''Compute the iso-barycenter of a set (or list) of Point3d.
@@ -703,6 +752,7 @@ class Edge(NamedTuple):
   p1: Point3d
   idx0: int = -1
   idx1: int = -1
+  hasTexture: bool = False
  
   def hashCode(self):
     return (min(self.idx0, self.idx1) << 32) | max(self.idx0, self.idx1)
